==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionButtonClickEventArgsDescription } from "./PropertyEditorPropertyDescriptionButtonClickEventArgsDescription";
/**
 * @hidden
 */
export let PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a == null) {
                PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
            }
            if (a.j(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.b(a);
            a.aa("PropertyEditorPropertyDescriptionButtonClickEventArgs", () => new PropertyEditorPropertyDescriptionButtonClickEventArgsDescription());
            a.z("PropertyEditorPropertyDescriptionButtonClickEventArgs", PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
        }
    }
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionButtonClickEventArgsDescription } from "./PropertyEditorPropertyDescriptionButtonClickEventArgsDescription";
/**
 * @hidden
 */
export let PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a == null) {
                PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
            }
            if (a.k(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.b(a);
            a.ac("PropertyEditorPropertyDescriptionButtonClickEventArgs", () => new PropertyEditorPropertyDescriptionButtonClickEventArgsDescription());
            a.ab("PropertyEditorPropertyDescriptionButtonClickEventArgs", PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
        }
    }
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata;
})();
